# Torch Sparks - Tools for PyTorch in Pure Python

## Get Started

```bash
pip install torchsparks
```

## Docs

Click [here](https://chuanwise.feishu.cn/wiki/LDe5wAeQaiif9qkiY0hcKpAinuh?from=from_github_repo) to see the docs! 

## License

This project is licensed under the [Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0). 

```text
Copyright 2024 Chuanwise and contributors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```
